==> ejc-middlemeasurement-impl-3.0.0-20221024.101540-187-sources.jar: com/ejianc/business/middlemeasurement/bean/EngineermeasurementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程计量台账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_engineermeasurementdetail")
public class EngineermeasurementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表Id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="image_progress")
    private java.lang.String imageProgress; // 形象进度
    @TableField(value="ispecific_date")
    private java.util.Date ispecificDate; // 年月日
    @TableField(value="civil_engineering")
    private java.math.BigDecimal civilEngineering; // 土建
    @TableField(value="install")
    private java.math.BigDecimal install; // 安装
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="actual_civil_engineering")
    private java.math.BigDecimal actualCivilEngineering; // 土建
    @TableField(value="actual_install")
    private java.math.BigDecimal actualInstall; // 安装
    @TableField(value="actual_total")
    private java.math.BigDecimal actualTotal; // 合计
    @TableField(value="financial_income")
    private java.math.BigDecimal financialIncome; // 财务列报收入
    @TableField(value="actual_cost")
    private java.math.BigDecimal actualCost; // 实际成本
    @TableField(value="right_confirmation_rate")
    private java.math.BigDecimal rightConfirmationRate; // 确权率
    @TableField(value="contract_approval_time")
    private java.util.Date contractApprovalTime; // 合同审批时间
    @TableField(value="actual_reporting_time")
    private java.util.Date actualReportingTime; // 实际上报时间
    @TableField(value="actual_approval_time")
    private java.util.Date actualApprovalTime; // 实际审批时间
    @TableField(value="amount_agreed_receivables")
    private java.math.BigDecimal amountAgreedReceivables; // 合同约定应收款金额
    @TableField(value="amount_collected")
    private java.math.BigDecimal amountCollected; // 收款金额
    @TableField(value="among_civil_engineering")
    private java.math.BigDecimal amongCivilEngineering; // 土建
    @TableField(value="among_install")
    private java.math.BigDecimal amongInstall; // 安装
    @TableField(value="agreed_collection_time")
    private java.util.Date agreedCollectionTime; // 合同约定收款时间
    @TableField(value="actual_collection_time")
    private java.util.Date actualCollectionTime; // 实际收款时间
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 主表Id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表Id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 形象进度
     */
    public java.lang.String getImageProgress() {
        return imageProgress;
    }

    /**
     * 形象进度
     */
    public void setImageProgress(java.lang.String imageProgress) {
        this.imageProgress = imageProgress;
    }
    /**
     * 年月日
     */
    public java.util.Date getIspecificDate() {
        return ispecificDate;
    }

    /**
     * 年月日
     */
    public void setIspecificDate(java.util.Date ispecificDate) {
        this.ispecificDate = ispecificDate;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilEngineering() {
        return civilEngineering;
    }

    /**
     * 土建
     */
    public void setCivilEngineering(java.math.BigDecimal civilEngineering) {
        this.civilEngineering = civilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstall() {
        return install;
    }

    /**
     * 安装
     */
    public void setInstall(java.math.BigDecimal install) {
        this.install = install;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getActualCivilEngineering() {
        return actualCivilEngineering;
    }

    /**
     * 土建
     */
    public void setActualCivilEngineering(java.math.BigDecimal actualCivilEngineering) {
        this.actualCivilEngineering = actualCivilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getActualInstall() {
        return actualInstall;
    }

    /**
     * 安装
     */
    public void setActualInstall(java.math.BigDecimal actualInstall) {
        this.actualInstall = actualInstall;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getActualTotal() {
        return actualTotal;
    }

    /**
     * 合计
     */
    public void setActualTotal(java.math.BigDecimal actualTotal) {
        this.actualTotal = actualTotal;
    }
    /**
     * 财务列报收入
     */
    public java.math.BigDecimal getFinancialIncome() {
        return financialIncome;
    }

    /**
     * 财务列报收入
     */
    public void setFinancialIncome(java.math.BigDecimal financialIncome) {
        this.financialIncome = financialIncome;
    }
    /**
     * 实际成本
     */
    public java.math.BigDecimal getActualCost() {
        return actualCost;
    }

    /**
     * 实际成本
     */
    public void setActualCost(java.math.BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    /**
     * 确权率
     */
    public java.math.BigDecimal getRightConfirmationRate() {
        return rightConfirmationRate;
    }

    /**
     * 确权率
     */
    public void setRightConfirmationRate(java.math.BigDecimal rightConfirmationRate) {
        this.rightConfirmationRate = rightConfirmationRate;
    }
    /**
     * 合同审批时间
     */
    public java.util.Date getContractApprovalTime() {
        return contractApprovalTime;
    }

    /**
     * 合同审批时间
     */
    public void setContractApprovalTime(java.util.Date contractApprovalTime) {
        this.contractApprovalTime = contractApprovalTime;
    }
    /**
     * 实际上报时间
     */
    public java.util.Date getActualReportingTime() {
        return actualReportingTime;
    }

    /**
     * 实际上报时间
     */
    public void setActualReportingTime(java.util.Date actualReportingTime) {
        this.actualReportingTime = actualReportingTime;
    }
    /**
     * 实际审批时间
     */
    public java.util.Date getActualApprovalTime() {
        return actualApprovalTime;
    }

    /**
     * 实际审批时间
     */
    public void setActualApprovalTime(java.util.Date actualApprovalTime) {
        this.actualApprovalTime = actualApprovalTime;
    }
    /**
     * 合同约定应收款金额
     */
    public java.math.BigDecimal getAmountAgreedReceivables() {
        return amountAgreedReceivables;
    }

    /**
     * 合同约定应收款金额
     */
    public void setAmountAgreedReceivables(java.math.BigDecimal amountAgreedReceivables) {
        this.amountAgreedReceivables = amountAgreedReceivables;
    }
    /**
     * 收款金额
     */
    public java.math.BigDecimal getAmountCollected() {
        return amountCollected;
    }

    /**
     * 收款金额
     */
    public void setAmountCollected(java.math.BigDecimal amountCollected) {
        this.amountCollected = amountCollected;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getAmongCivilEngineering() {
        return amongCivilEngineering;
    }

    /**
     * 土建
     */
    public void setAmongCivilEngineering(java.math.BigDecimal amongCivilEngineering) {
        this.amongCivilEngineering = amongCivilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getAmongInstall() {
        return amongInstall;
    }

    /**
     * 安装
     */
    public void setAmongInstall(java.math.BigDecimal amongInstall) {
        this.amongInstall = amongInstall;
    }
    /**
     * 合同约定收款时间
     */
    public java.util.Date getAgreedCollectionTime() {
        return agreedCollectionTime;
    }

    /**
     * 合同约定收款时间
     */
    public void setAgreedCollectionTime(java.util.Date agreedCollectionTime) {
        this.agreedCollectionTime = agreedCollectionTime;
    }
    /**
     * 实际收款时间
     */
    public java.util.Date getActualCollectionTime() {
        return actualCollectionTime;
    }

    /**
     * 实际收款时间
     */
    public void setActualCollectionTime(java.util.Date actualCollectionTime) {
        this.actualCollectionTime = actualCollectionTime;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20221110.120346-230-sources.jar: com/ejianc/business/middlemeasurement/bean/EngineermeasurementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 工程计量台账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_engineermeasurementdetail")
public class EngineermeasurementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表Id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="image_progress")
    private java.lang.String imageProgress; // 形象进度
    @TableField(value="ispecific_date")
    private java.util.Date ispecificDate; // 年月日
    @TableField(value="civil_engineering")
    private java.math.BigDecimal civilEngineering; // 土建
    @TableField(value="install")
    private java.math.BigDecimal install; // 安装
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="actual_civil_engineering")
    private java.math.BigDecimal actualCivilEngineering; // 土建
    @TableField(value="actual_install")
    private java.math.BigDecimal actualInstall; // 安装
    @TableField(value="actual_total")
    private java.math.BigDecimal actualTotal; // 合计
    @TableField(value="financial_income")
    private java.math.BigDecimal financialIncome; // 财务列报收入
    @TableField(value="actual_cost")
    private java.math.BigDecimal actualCost; // 实际成本
    @TableField(value="right_confirmation_rate")
    private java.math.BigDecimal rightConfirmationRate; // 确权率
    @TableField(value="contract_approval_time")
    private java.util.Date contractApprovalTime; // 合同审批时间
    @TableField(value="actual_reporting_time")
    private java.util.Date actualReportingTime; // 实际上报时间
    @TableField(value="actual_approval_time")
    private java.util.Date actualApprovalTime; // 实际审批时间
    @TableField(value="amount_agreed_receivables")
    private java.math.BigDecimal amountAgreedReceivables; // 合同约定应收款金额
    @TableField(value="amount_collected")
    private java.math.BigDecimal amountCollected; // 收款金额
    @TableField(value="among_civil_engineering")
    private java.math.BigDecimal amongCivilEngineering; // 土建
    @TableField(value="among_install")
    private java.math.BigDecimal amongInstall; // 安装
    @TableField(value="agreed_collection_time")
    private java.util.Date agreedCollectionTime; // 合同约定收款时间
    @TableField(value="actual_collection_time")
    private java.util.Date actualCollectionTime; // 实际收款时间
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="declare_engineering")
    private BigDecimal declareEngineering; // 土建——申报工程量
    @TableField(value="declare_install")
    private BigDecimal declareInstall; // 安装——申报工程量
    @TableField(value="declare_total")
    private BigDecimal declareTotal; // 合计——申报工程量
    
    
    

    /**
     * 主表Id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表Id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 形象进度
     */
    public java.lang.String getImageProgress() {
        return imageProgress;
    }

    /**
     * 形象进度
     */
    public void setImageProgress(java.lang.String imageProgress) {
        this.imageProgress = imageProgress;
    }
    /**
     * 年月日
     */
    public java.util.Date getIspecificDate() {
        return ispecificDate;
    }

    /**
     * 年月日
     */
    public void setIspecificDate(java.util.Date ispecificDate) {
        this.ispecificDate = ispecificDate;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilEngineering() {
        return civilEngineering;
    }

    /**
     * 土建
     */
    public void setCivilEngineering(java.math.BigDecimal civilEngineering) {
        this.civilEngineering = civilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstall() {
        return install;
    }

    /**
     * 安装
     */
    public void setInstall(java.math.BigDecimal install) {
        this.install = install;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getActualCivilEngineering() {
        return actualCivilEngineering;
    }

    /**
     * 土建
     */
    public void setActualCivilEngineering(java.math.BigDecimal actualCivilEngineering) {
        this.actualCivilEngineering = actualCivilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getActualInstall() {
        return actualInstall;
    }

    /**
     * 安装
     */
    public void setActualInstall(java.math.BigDecimal actualInstall) {
        this.actualInstall = actualInstall;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getActualTotal() {
        return actualTotal;
    }

    /**
     * 合计
     */
    public void setActualTotal(java.math.BigDecimal actualTotal) {
        this.actualTotal = actualTotal;
    }
    /**
     * 财务列报收入
     */
    public java.math.BigDecimal getFinancialIncome() {
        return financialIncome;
    }

    /**
     * 财务列报收入
     */
    public void setFinancialIncome(java.math.BigDecimal financialIncome) {
        this.financialIncome = financialIncome;
    }
    /**
     * 实际成本
     */
    public java.math.BigDecimal getActualCost() {
        return actualCost;
    }

    /**
     * 实际成本
     */
    public void setActualCost(java.math.BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    /**
     * 确权率
     */
    public java.math.BigDecimal getRightConfirmationRate() {
        return rightConfirmationRate;
    }

    /**
     * 确权率
     */
    public void setRightConfirmationRate(java.math.BigDecimal rightConfirmationRate) {
        this.rightConfirmationRate = rightConfirmationRate;
    }
    /**
     * 合同审批时间
     */
    public java.util.Date getContractApprovalTime() {
        return contractApprovalTime;
    }

    /**
     * 合同审批时间
     */
    public void setContractApprovalTime(java.util.Date contractApprovalTime) {
        this.contractApprovalTime = contractApprovalTime;
    }
    /**
     * 实际上报时间
     */
    public java.util.Date getActualReportingTime() {
        return actualReportingTime;
    }

    /**
     * 实际上报时间
     */
    public void setActualReportingTime(java.util.Date actualReportingTime) {
        this.actualReportingTime = actualReportingTime;
    }
    /**
     * 实际审批时间
     */
    public java.util.Date getActualApprovalTime() {
        return actualApprovalTime;
    }

    /**
     * 实际审批时间
     */
    public void setActualApprovalTime(java.util.Date actualApprovalTime) {
        this.actualApprovalTime = actualApprovalTime;
    }
    /**
     * 合同约定应收款金额
     */
    public java.math.BigDecimal getAmountAgreedReceivables() {
        return amountAgreedReceivables;
    }

    /**
     * 合同约定应收款金额
     */
    public void setAmountAgreedReceivables(java.math.BigDecimal amountAgreedReceivables) {
        this.amountAgreedReceivables = amountAgreedReceivables;
    }
    /**
     * 收款金额
     */
    public java.math.BigDecimal getAmountCollected() {
        return amountCollected;
    }

    /**
     * 收款金额
     */
    public void setAmountCollected(java.math.BigDecimal amountCollected) {
        this.amountCollected = amountCollected;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getAmongCivilEngineering() {
        return amongCivilEngineering;
    }

    /**
     * 土建
     */
    public void setAmongCivilEngineering(java.math.BigDecimal amongCivilEngineering) {
        this.amongCivilEngineering = amongCivilEngineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getAmongInstall() {
        return amongInstall;
    }

    /**
     * 安装
     */
    public void setAmongInstall(java.math.BigDecimal amongInstall) {
        this.amongInstall = amongInstall;
    }
    /**
     * 合同约定收款时间
     */
    public java.util.Date getAgreedCollectionTime() {
        return agreedCollectionTime;
    }

    /**
     * 合同约定收款时间
     */
    public void setAgreedCollectionTime(java.util.Date agreedCollectionTime) {
        this.agreedCollectionTime = agreedCollectionTime;
    }
    /**
     * 实际收款时间
     */
    public java.util.Date getActualCollectionTime() {
        return actualCollectionTime;
    }

    /**
     * 实际收款时间
     */
    public void setActualCollectionTime(java.util.Date actualCollectionTime) {
        this.actualCollectionTime = actualCollectionTime;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public BigDecimal getDeclareEngineering() {
        return declareEngineering;
    }

    public void setDeclareEngineering(BigDecimal declareEngineering) {
        this.declareEngineering = declareEngineering;
    }

    public BigDecimal getDeclareInstall() {
        return declareInstall;
    }

    public void setDeclareInstall(BigDecimal declareInstall) {
        this.declareInstall = declareInstall;
    }

    public BigDecimal getDeclareTotal() {
        return declareTotal;
    }

    public void setDeclareTotal(BigDecimal declareTotal) {
        this.declareTotal = declareTotal;
    }
}
